# CHANGELOG


## v0.6.0 (2025-01-10)

### Bug Fixes

- Version comparison
  ([`3ac7596`](https://github.com/gtaylor/baymesh-cli/commit/3ac759662e4df0c2d4619cc09498706d2d188ada))

### Chores

- Bump dependencies
  ([`53be031`](https://github.com/gtaylor/baymesh-cli/commit/53be031a85cb04ca5e1781682786eca6d903607e))

- Commit the updated uv.lock version
  ([`b7cb817`](https://github.com/gtaylor/baymesh-cli/commit/b7cb817de09cb1e7262bc4cfd4c19f4109c3d28e))

- Remove Homebrew release stuff from CI
  ([`4f81bb5`](https://github.com/gtaylor/baymesh-cli/commit/4f81bb57c52d1192bde05cc9970cea9bd0747df3))

### Features

- Add node setup wizard
  ([`c5d8e39`](https://github.com/gtaylor/baymesh-cli/commit/c5d8e39633c8241349b2fa33fc8d19e3fff6a412))

The wizard will walk the user through configuring the essential settings for the node. For ex: LoRa
  preset, long/short names, etc.

- Add version checking
  ([`31bc074`](https://github.com/gtaylor/baymesh-cli/commit/31bc0740c299840c94f3242e9253ca758ae18e5d))

Since the recommended configs may change over time, it's important that users stay up to date. This
  commit adds a facility for checking for updates and notifying the user if a newer version is
  available.

For now we're checking on every command invocation, but we can cache this in the future if it
  becomes problematic.


## v0.5.1 (2025-01-07)

### Bug Fixes

- Pull Homebrew bump into ci.yml
  ([`a1d6bb8`](https://github.com/gtaylor/baymesh-cli/commit/a1d6bb8681e05829d751249b93dd000b0f29ac31))


## v0.5.0 (2025-01-07)

### Features

- Unveil the new Homebrew tap
  ([`4032861`](https://github.com/gtaylor/baymesh-cli/commit/4032861a3691102c04261c88572db1ace8a64aa0))


## v0.4.0 (2025-01-07)

### Documentation

- Remove testing changelog entries
  ([`73196b6`](https://github.com/gtaylor/baymesh-cli/commit/73196b686997f08f343fc20e5d50f6c0a6462085))

### Features

- Automate the release to baymesh Homebrew tap
  ([`b90fff0`](https://github.com/gtaylor/baymesh-cli/commit/b90fff04aa0198303d4197147177d708b5acfde6))


## v0.3.3 (2025-01-05)

### Bug Fixes

- Fix release for real this time
  ([`caaa9c9`](https://github.com/gtaylor/baymesh-cli/commit/caaa9c961570089a77f528889db14ce9cfdd1538))


## v0.3.2 (2025-01-05)

### Bug Fixes

- Fix release for real this time
  ([`eab6a5b`](https://github.com/gtaylor/baymesh-cli/commit/eab6a5b9d9de74bc0afec7bc84116f6101881ef9))


## v0.3.1 (2025-01-05)

### Bug Fixes

- Remove now-unused release.yml
  ([`7ed0adc`](https://github.com/gtaylor/baymesh-cli/commit/7ed0adca911258a5693af43e57eab24f73395276))


## v0.3.0 (2025-01-05)

### Features

- Attempt release automation fix
  ([`2ead208`](https://github.com/gtaylor/baymesh-cli/commit/2ead2082f217634a73445463f5fd918032370a32))


## v0.2.0 (2025-01-05)

### Features

- Attempt release automation fix
  ([`bb18bf7`](https://github.com/gtaylor/baymesh-cli/commit/bb18bf73cdadee6f3f83273460b772d950a6f2a5))


## v0.1.0 (2025-01-05)

### Documentation

- Add dev setup to README.md
  ([`3b72ec4`](https://github.com/gtaylor/baymesh-cli/commit/3b72ec4284b901d50b216ef75ac047283e72ebd3))

### Features

- Graduating to alpha
  ([`5015cfc`](https://github.com/gtaylor/baymesh-cli/commit/5015cfcf65d473e4a52a4173f475a6aa797b2649))


## v0.0.0 (2025-01-05)
